
# Ramchet module

---

This is a tool for upgrading the DataCanvas Platform.

---

## Installation

Our latest stable is always available on PyPi.

```Shell
pip install ramchet
```

---

## Documentation

You can set up few parameters for this tool

```Shell
$ ramchet --help
Usage: ramchet [OPTIONS] COMMAND [ARGS]...

Options:
  -v, --version
  --help         Show this message and exit.

Commands:
  command     Get startting docker container command of one...
  components  Get versions of all components for upgrading
  update      update one component
  version     Get version of one component
```

---

## Contact

If you have any questions, welcome to send an email to <a class="email" href="mailto:xiaoh@about.me">xiaoh@about.me</a>

---

### END

